import OpenAI from 'openai';
import { getApiKey } from './config.js';

export const generateCommitMessage = async (changes) => {
  const apiKey = getApiKey('openai');
  if (!apiKey) {
    throw new Error('OpenAI API key not found. Please set it using: cligitmessageai ai --openai YOUR_KEY');
  }

  const openai = new OpenAI({
    apiKey: apiKey
  });

  const changesSummary = [
    changes.staged.length ? `Staged files: ${changes.staged.join(', ')}` : '',
    changes.modified.length ? `Modified files: ${changes.modified.join(', ')}` : '',
    changes.created.length ? `Created files: ${changes.created.join(', ')}` : '',
    changes.deleted.length ? `Deleted files: ${changes.deleted.join(', ')}` : '',
    `\nStaged changes:\n${changes.stagedDiff}`,
    `\nUnstaged changes:\n${changes.unstagedDiff}`
  ].filter(Boolean).join('\n');

  const response = await openai.chat.completions.create({
    model: "gpt-4o-mini",
    messages: [
      {
        role: "system",
        content: "You are a helpful assistant that generates clear and concise git commit messages. Follow these rules:\n" +
                "1. Use the conventional commits format (type(scope): description)\n" +
                "2. Keep the message under 72 characters\n" +
                "3. Use the imperative mood (e.g., 'add' not 'adds')\n" +
                "4. Be descriptive but concise\n" +
                "5. Focus on WHY and WHAT, not HOW"
      },
      {
        role: "user",
        content: `Generate a commit message for these changes:\n\n${changesSummary}`
      }
    ],
    temperature: 0.7,
    max_tokens: 100
  });

  return response.choices[0].message.content.trim();
}; 